#
# spec file for package kweather
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0
%define plasma6_version 5.27.80

%bcond_without released
Name:           kweather
Version:        24.12.2
Release:        1.1
License:        GPL-2.0-or-later
Summary:        Weather application for Plasma
URL:            https://apps.kde.org/kweather
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KWeatherCore) >= 0.8
BuildRequires:  cmake(KF6Kirigami) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons) >= 0.11
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(Plasma) >= %{plasma6_version}
BuildRequires:  cmake(Qt6Charts) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6OpenGL) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
Requires:       kf6-kholidays-imports >= %{kf6_version}
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kirigami-addons6
Requires:       qt6-charts-imports >= %{qt6_version}

%description
A convergent weather application for Plasma. Has flat and dynamic/animated
views for showing forecasts and other information.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%files
%license LICENSES/*
%{_datadir}/dbus-1/services/org.kde.kweather.service
%{_kf6_applicationsdir}/org.kde.kweather.desktop
%{_kf6_appstreamdir}/org.kde.kweather.appdata.xml
%{_kf6_appstreamdir}/org.kde.plasma.kweather_1x4.appdata.xml
%{_kf6_bindir}/kweather
%{_kf6_iconsdir}/hicolor/scalable/apps/org.kde.kweather.svg
%dir %{_kf6_plasmadir}/plasmoids
%{_kf6_plasmadir}/plasmoids/org.kde.plasma.kweather_1x4/
%{_kf6_plugindir}/plasma/applets/plasma_applet_kweather_1x4.so

%files lang -f %{name}.lang

%changelog
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- Changes since 24.12.1:
  * Remove unused string from Android manifest
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- Changes since 24.12.0:
  * Update Android Gradle plugin version to 8.6.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- No code change since 24.11.80
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * Don't include quiet packages in feature_summary
  * fix clang-format
  * Add symbolic weather icon in the header of dynamic forecast page
  * Simplify AppStream summary
  * Align weather forecast
  * Don't show seconds in time stamps
  * Update look of dynamic forecast page
  * Use better icons in cards
  * Rework setup wizard
  * Remove add current location button because it doesn't work
  * Fix page behavior
  * Use Qt.createComponent to replace dedicated AboutPage.qml
  * Fix up 746f299
  * Main: Store window state using KConfig.WindowStateSaver
  * Fix reuse compliance
  * Add CMakePresets.json support
  * Convert .reuse/dep5 to REUSE.toml
  * Add clang-format validation job
  * Initialize KCrash
  * Use ECMDeprecationSettings
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- Changes since 24.08.1:
  * Remove add current location button because it doesn't work
  * Fix page behavior
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * snap: change source
  * snap: remove some plugs
  * ci: reenable other ci jobs
  * snap: remove `QML2_IMPORT_PATH` from build env
  * snap: remove cleanup part and add some more plugs
  * snap: add more build packages
  * snap: added opengl related dev libraries
  * ci: added snap build job
  * snap: update to latest release
  * Don't build the Plasmoid in Flatpak
  * Build APKs against released frameworks
  * Remove screenshots from the repository, use cdn.kde.org
  * Run qmlformat
  * Use typed list when exposing data to QML
  * Qualify property lookup
  * Mark WeatherLocation as uncreatable
  * Specify QML module dependency
  * Remove unused CMake file
  * Add detailed icons to Android
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Changes since 24.02.2:
  * const'ify pointer
  * Fix copyright
  * Make compile with QT_NO_CONTEXTLESS_CONNECT
  * Remove custom appstream check
  * Fix licensecheck on the CI
  * ci: Make use of Ubuntu:devel This updates appstream version to 1.0
  * Complement and Update org.kde.kweather.appdata.xml
  * Don't enable page dragging between locations unless it's touch input
  * CI: Flatpak: Add libplasma
  * flatpak: Switch to non-preview runtime
  * appstream: Update developer name
  * ci: Use ubuntu runner
  * ci: Add tag to appstream test
  * Add appstream CI test
  * Update Project Link in Readme
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * CI: Flatpak: Add libplasma
  * flatpak: Switch to non-preview runtime
  * appstream: Update developer name
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * Adapt to plasma-framework moving to Plasma
  * CI: Comment out flatpak CI it uses some KF6 dependencies
  * Add snapcraft file to reuse.
  * snapcraft: initial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * flatpak: update runtime to 22.08
  * Fix syntax of dep5 copyright statements
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Fix binary stripping of APKs with Qt 5.15.10
  * Fix includes
  * Fix flat screenshot
  * Update screenshots
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Sat Jun 17 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Add runtime dep on QtCharts QML module (boo#1212470)
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Mon Mar 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Sat Feb 20 2021 Andrés B.S. <andresbs@opensuse.org>
- Added kweathercore as a requirement
